import React from 'react';
import { TableFetchDataProps, TableGroupHeaderProps, TableModelProps } from './table.model';
import { DoifDataProps } from '../../props/DoifCommonProps';
interface TableProps {
    /** Table Data 배열 */
    data: Object[];
    /** Table 모델 배열 */
    model: TableModelProps[];
    /** caption을 설정합니다. */
    caption: string;
    /** `Table`컴포넌트의 높이를 설정합니다. */
    height: string;
    /** `Table` 컴포넌트의 넓이를 설정합니다. */
    width: string;
    /** `Button` 배열입니다. */
    buttons?: React.ReactNode;
    /** multi select 여부입니다. */
    enableMultiSelectRow: boolean;
    /** tree 구조 테이블 여부입니다. */
    enableTreeTable: boolean;
    /** tree 구조 테이블 row exapnd 여부입니다. true면 펼쳐놓고 false면 접습니다. */
    treeTableRowExpanded: boolean;
    /** 컬럼 sorting 여부입니다. */
    disableSortBy: boolean;
    /** 필터링 헤더 여부입니다. */
    disableFilters: boolean;
    /** 페이지 사이즈를 설정합니다. */
    initPageSize: number;
    /** 페이지 시작 위치를 설정합니다. */
    initPageIndex: number;
    /** 페이지 사이즈 배열입니다. */
    pageSizeArray: DoifDataProps[];
    /** group header를 설정하기 위한 배열입니다. */
    groupHeaders?: TableGroupHeaderProps[];
    /** loading 여부입니다. */
    loading: boolean;
    /** server side pagination 여부입니다. */
    enableServerSidePagination: boolean;
    /** pageCount */
    pageCount: number;
    /** 데이터의 총 갯수를 나타냅니다. Server Side Pagination 사용 시 필요합니다. */
    totalCount?: number;
    /** server side pagination을 할 때 data를 불러오는 콜백함수 입니다. */
    onFetchData?: ({ pageSize, pageIndex }: TableFetchDataProps) => void;
    /** row를 선택했을 때 실행되는 콜백함수 입니다. */
    onSelectRow?: (id: string, rowValue: Object) => void;
    /** row를 더블클릭 했을 때 실행되는 콜백함수 입니다. */
    onDoubleClickRow?: (id: string, rowValue: Object) => void;
    /** mulit row를 선택했을 때 실행되는 콜백함수 입니다. */
    onMultiSelectRow?: (rowValues: Object[]) => void;
}
declare const _default: React.MemoExoticComponent<{
    ({ model, data, caption, width, height, buttons, enableMultiSelectRow, enableTreeTable, treeTableRowExpanded, disableSortBy, disableFilters, initPageSize, initPageIndex, pageSizeArray, groupHeaders, loading, enableServerSidePagination, pageCount: controlledPageCount, totalCount, onFetchData, onSelectRow, onDoubleClickRow, onMultiSelectRow, }: TableProps): JSX.Element;
    defaultProps: {
        width: string;
        height: string;
        enableMultiSelectRow: boolean;
        treeTableRowExpanded: boolean;
        enableTreeTable: boolean;
        disableSortBy: boolean;
        disableFilters: boolean;
        initPageSize: number;
        initPageIndex: number;
        pageSizeArray: {
            code: string;
            name: string;
        }[];
        loading: boolean;
        enableServerSidePagination: boolean;
        pageCount: number;
    };
}>;
export default _default;
